@@ -61,7 +61,7 @@ class MoFirefly(SwarmAlgorithm):
         self.dominance = ParetoDominance()
 
         # set random generator
-        self.individual_features['dominate'] = set()
+        self.individual_features['dominate'] = []
         self.individual_features['crowding_distance'] = 0
         self.individual_features['domination_counter'] = 0
         self.individual_features['front_number'] = 0
