@@ -2,9 +2,9 @@
  Module is dedicated to describe optimization problem.
 """
 
-from .datastore import SqliteDataStore, DummyDataStore
-from .utils import ConfigDictionary
-from .surrogate import SurrogateModelEval
+from datastore import SqliteDataStore, DummyDataStore
+from utils import ConfigDictionary
+from artap.surrogate import SurrogateModelEval
 from abc import abstractmethod
 
 import logging
@@ -154,7 +154,8 @@ class Problem:
         return self.population(max_index)
 
     def to_dict(self):
-        output = {'name': self.name, 'description': self.description, 'parameters': self.parameters}
+        parameters = list(self.parameters)
+        output = {'name': self.name, 'description': self.description, 'parameters': parameters}
         return output
 
     @staticmethod
