@@ -1,5 +1,6 @@
 import csv
 from .quality_indicator import gd, epsilon_add
+from matplotlib import pylab, rc, axis
 
 
 class Results:
@@ -7,6 +8,24 @@ class Results:
 
     def __init__(self, problem):
         self.problem = problem
+        self.use_latex = True
+        self.label_size = 16
+        self.tick_size = 14
+        self.title_size = 18
+        self.legend = True
+        self.width = 8
+        self.hight = 5
+
+        if self.use_latex:
+            # allows using Latex
+            rc('font', **{'family': ' DejaVu Sans', 'sans-serif': ['Helvetica']})
+            rc('text', usetex=True)
+
+        # sets the legend font size
+        params = {'legend.fontsize': 14,
+                  'legend.handlelength': 2}
+
+        pylab.rcParams.update(params)
 
     def parameter_names(self):
         parameter_names = []
@@ -68,8 +87,10 @@ class Results:
         # Returns population with given index
         #if population_id >= len(self.problem.populations):
         #    raise ValueError('Index of population exceeds the number of populations.')
-
-        individuals = self.problem.population(population_id)
+        if population_id == -1:
+            individuals = self.problem.last_population()
+        else:
+            individuals = self.problem.population(population_id)
         return individuals
 
     def goal_on_index(self, name=None, population_id=-1):
@@ -127,7 +148,12 @@ class Results:
         :return: list of two lists, the first contains sorted parameter values, the second values of selected goal
         function
         """
-        individuals = self.population(population_id)
+
+        if population_id == -1:
+            individuals = self.problem.last_population()
+        else:
+            individuals = self.population(population_id)
+
         parameter_index = self.parameter_index(parameter_name)
         goal_index = self.goal_index(goal_name)
         parameter_values = []
@@ -137,7 +163,7 @@ class Results:
             parameter_values.append(individual.vector[parameter_index])
             goal_values.append(individual.costs[goal_index])
 
-        if sorted:
+        if sorted is True:
             goal_values = self.sort_list(parameter_values, goal_values)
             parameter_values.sort()
 
@@ -176,7 +202,7 @@ class Results:
         with open(filename, 'w', newline='') as f:
             writer = csv.writer(f)
             # names
-            out = []
+            out = ["population_id"]
             for parameter in self.problem.parameters:
                 out.append(parameter["name"])
             for cost in self.problem.costs:
@@ -185,15 +211,17 @@ class Results:
             writer.writerows([out])
 
             # values
+            population_id = 0
             for individuals in self.problem.populations().values():
                 for individual in individuals:
-                    out = []
+                    out = [population_id]
                     for i in individual.costs:
                         out.append(i)
                     for j in individual.vector:
                         out.append(j)
 
                     writer.writerows([out])
+                population_id += 1
 
     def pareto_front(self, population_id=None):
         """
@@ -291,35 +319,123 @@ class Results:
 
         return result
 
-    # TODO: remove or add to special class and file
-    def pareto_plot(self, cost_x=0, cost_y=1):
+    def set_figure(self):
+        # We change the fontsize of minor ticks label
+        fig, ax = pylab.subplots(figsize=(self.width, self.hight))
+        ax.tick_params(axis='both', which='major', labelsize=self.tick_size)
+        ax.tick_params(axis='both', which='minor', labelsize=self.tick_size)
+        ax.grid()
+        # ax.grid(color='grey', linestyle='-', linewidth=0.25, alpha=0.5)
+        # removing top and right borders
+        # ax.spines['top'].set_visible(False)
+        # ax.spines['right'].set_visible(False)  # adds major gridlines
+        return [fig, ax]
+
+    def get_objectives_plot(self):
+
+        fig, ax = self.set_figure()
+        all_individuals = self.costs()
+        for point in all_individuals:
+            ax.plot(point[0], point[1], '.')
+
+        pareto = self.pareto_front()
+        ax.plot(pareto[0], pareto[1], 'ro', label='Last Pareto front')
+
+        ax.set_xlabel(r'$F_1$', fontsize=self.label_size)
+        ax.set_ylabel(r'$F_2$', fontsize=self.label_size)
+        ax.legend()
+        return [fig, ax]
+
+    def objectives_plot(self):
+        fig, ax = self.get_objectives_plot()
+        fig.show()
+
+    def get_pareto_plot(self, cost_x=0, cost_y=1):
         """
         A simple 2d - pareto plot from the variable 1 and 2 by default.
         :return:
         """
-
+        fig, ax = self.set_figure()
         pvalues = self.pareto_values()
 
         x = [i[cost_x] for i in pvalues]
         y = [i[cost_y] for i in pvalues]
 
-        import pylab as plt
-
-        fig, ax = plt.subplots(figsize=(10, 5))  # customizes alpha for each dot in the scatter plot
         ax.scatter(x, y, alpha=0.80)
 
         # adds a title and axes labels
         x_name = self.problem.costs[cost_x]['name']
         y_name = self.problem.costs[cost_y]['name']
 
-        ax.set_title('Pareto values')
-        ax.set_xlabel(x_name)
-        ax.set_ylabel(y_name)
+        ax.set_title('Pareto values', fontsize=self.title_size)
+        ax.set_xlabel('$' + x_name + '$', fontsize=self.label_size)
+        ax.set_ylabel('$' + y_name + '$', fontsize=self.label_size)
+        return [fig, ax]
 
-        # removing top and right borders
-        ax.spines['top'].set_visible(False)
-        ax.spines['right'].set_visible(False)  # adds major gridlines
-        ax.grid(color='grey', linestyle='-', linewidth=0.25, alpha=0.5)
 
-        plt.show()
-        return
+    def pareto_plot(self, cost_x=0, cost_y=1):
+        fig, ax = self.get_pareto_plot(cost_x, cost_y)
+        fig.show()
+
+    def get_goal_on_index(self, name, population_id=-1):
+        fig, ax = self.set_figure()
+        table = self.goal_on_index(name=name, population_id=population_id)
+        ax.plot(table[0], table[1])
+
+        ax.set_xlabel(r'$k$', fontsize=self.label_size)
+        ax.set_ylabel(r'$' + name + '$', fontsize=self.label_size)
+        return [fig, ax]
+
+    def goal_on_index_plot(self, name, population_id=-1):
+        fig, ax = self.get_goal_on_index(name, population_id)
+        fig.show()
+
+    def get_parameter_on_index(self, name, population_id=-1):
+        fig, ax = self.set_figure()
+        table = self.parameter_on_index(name=name, population_id=population_id)
+        ax.plot(table[0], table[1])
+
+        ax.set_xlabel(r'$k$', fontsize=self.label_size)
+        ax.set_ylabel(r'$' + name + '$', fontsize=self.label_size)
+        return [fig, ax]
+
+    def parameter_on_index_plot(self, name, population_id=-1):
+        fig, ax = self.get_parameter_on_index(name, population_id)
+        fig.show()
+
+    def get_goal_on_parameter(self, parameter_name, goal_name, population_id=-1, sorted=False):
+        fig, ax = self.set_figure()
+        table = self.goal_on_parameter(parameter_name, goal_name, population_id, sorted)
+        ax.plot(table[0], table[1], 'o')
+
+        ax.set_xlabel(r'$' + parameter_name + '$', fontsize=self.label_size)
+        ax.set_ylabel(r'$' + goal_name + '$', fontsize=self.label_size)
+        return [fig, ax]
+
+    def goal_on_parameter_plot(self, parameter_name, goal_name, population_id=-1, sorted=False):
+        fig, ax = self.get_goal_on_parameter(parameter_name, goal_name, population_id, sorted)
+        fig.show()
+
+    def get_parameter_on_parameter(self, parameter_1, parameter_2, population_id=-1, sorted=False):
+        fig, ax = self.set_figure()
+        table = self.parameter_on_parameter(parameter_1, parameter_2, population_id, sorted)
+        ax.plot(table[0], table[1], 'o')
+
+        ax.set_xlabel(r'$' + parameter_1 + '$', fontsize=self.label_size)
+        ax.set_ylabel(r'$' + parameter_2 + '$', fontsize=self.label_size)
+        return [fig, ax]
+
+    def parameter_on_parameter_plot(self, parameter_1, parameter_2, population_id=-1, sorted=False):
+        fig, ax = self.get_parameter_on_parameter(parameter_1, parameter_2, population_id, sorted)
+        fig.show()
+
+    def goal_histogram_plot(self, name, population_id=-1):
+        fig, ax = self.set_figure()
+        table = self.goal_on_index(name=name, population_id=population_id)
+        n, bins, patches = ax.hist(x=table[1], bins='auto', color='#0504aa',
+                                    alpha=0.7, rwidth=0.85)
+        fig.show()
+
+    def get_mean_confidence_interval(self, name):
+        index = self.goal_index(name)
+        return 
